==> haskell-smallcheck-1.2.1.1-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 smallcheck
version:              1.2.1.1
visibility:           public
id:                   smallcheck-1.2.1.1-7xuAaN6NMgqAPCcthmuXhk
key:                  smallcheck-1.2.1.1-7xuAaN6NMgqAPCcthmuXhk
license:              BSD-3-Clause
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Colin Runciman, Roman Cheplyaka
homepage:             https://github.com/Bodigrim/smallcheck
synopsis:             A property-based testing library
description:
    As of 2023, this library is largely obsolete: arbitrary test generators
    with shrinking such as [falsify](https://hackage.haskell.org/package/falsify)
    offer much better user experience.

    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.

category:             Testing
abi:                  353322ec42f8c7020ee5a34cfa20aa86
exposed:              True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series

hidden-modules:
    Test.SmallCheck.Property Test.SmallCheck.SeriesMonad
    Test.SmallCheck.Property.Result

import-dirs:          /usr/lib/ghc-9.2.8/site-local/smallcheck-1.2.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/smallcheck-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-smallcheck
hs-libraries:         HSsmallcheck-1.2.1.1-7xuAaN6NMgqAPCcthmuXhk
depends:
    base-4.16.4.0 logict-0.7.1.0-CvI0kbtBhHT3JSvqEPkh3l mtl-2.2.2
    pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html:         /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-smallcheck-1.2.1.1-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 smallcheck
version:              1.2.1.1
visibility:           public
id:                   smallcheck-1.2.1.1-AETUpJN2mFrLUsbEBN2yZv
key:                  smallcheck-1.2.1.1-AETUpJN2mFrLUsbEBN2yZv
license:              BSD-3-Clause
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Colin Runciman, Roman Cheplyaka
homepage:             https://github.com/Bodigrim/smallcheck
synopsis:             A property-based testing library
description:
    As of 2023, this library is largely obsolete: arbitrary test generators
    with shrinking such as [falsify](https://hackage.haskell.org/package/falsify)
    offer much better user experience.

    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.

category:             Testing
abi:                  58d76037de47766f26de112f9ed9c5de
exposed:              True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series

hidden-modules:
    Test.SmallCheck.Property Test.SmallCheck.SeriesMonad
    Test.SmallCheck.Property.Result

import-dirs:          /usr/lib/ghc-9.2.8/site-local/smallcheck-1.2.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/smallcheck-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-smallcheck
hs-libraries:         HSsmallcheck-1.2.1.1-AETUpJN2mFrLUsbEBN2yZv
depends:
    base-4.16.4.0 logict-0.7.1.0-F72Qzjd24pB409d2gc5t1L mtl-2.2.2
    pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html:         /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
